//
//  ISRecogenizeCard.h
//  ISBusinessCardSDK
//
//  Created by Simon liu on 17/02/15.
//  Copyright (c) 2017年 xzliu. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import <ISOpenSDKFoundation/ISOpenSDKFoundation.h>
#import "ISBCRDefine.h"

typedef void(^ConstructResourcesFinishHandler)(ISOpenSDKStatus status);

@interface ISRecogenizeCard : NSObject

/**
 *  A singleton method for ISRecogenizeCard, you should use this singleton to call other methods.
 *
 *  @return A ISRecogenizeCard instance.
 */
+ (ISRecogenizeCard *)sharedISOpenSDKController;

/*
 You should call this method to construct resources before call other APIs in the SDK, calling this API will cause an online authorization for the first time this SDK is used.Once authorized successfully, this API will be returned immediately within expire time and try to update authorization status in background
 */
/**
 *  Use this method to construct resources and authorize SDK. You should call this method before any other API.
 *
 *  @param appKey    The app key you apply for.
 *  @param subAppKey For further use, now is nil.
 *  @param handler   The construct result block. The status is defined in header file 'ISOpenSDKStatus.h'
 */
- (void)constructResourcesWithAppKey:(NSString *)appKey
                           subAppkey:(NSString *)subAppKey
                       finishHandler:(ConstructResourcesFinishHandler)handler;

/**
 *  Recognize card with recognize result content, if recognize failed, then return error.
 *
 *  @param cardImage              The image that need to be recognized.
 *  @param recognizeLanguages     Recognized languages that need to be preset, e.g. @[@(ISOCRLanguageTypeEnglish), @(ISOCRLanguageTypeChineseSimp), @(ISOCRLanguageTypeJapanese)].
 *  @param needProcess            If need to process image, please set to YES.
 *  @param recognizeResultHandler Return recognized result content and error if recognize failed.
 *  @param processResultHandler   Return processed image and error if process failed.
 *
 *  @return The authorize status, defined in header file 'ISOpenSDKStatus.h'
 */
- (ISOpenSDKStatus)recognizeCardWithImage:(UIImage *)cardImage
                        recognizeLanguage:(NSArray *)recognizeLanguages
                         needImageProcess:(BOOL)needProcess
                   recognizeResultHandler:(ISRecognizeResultHanler)recognizeResultHandler
                imageProcessResultHandler:(ISProcessCardResultHandler)processResultHandler;

/**
 *  Release resources, call when you want to finish recognize.
 */
- (void)destructResources;

/**
 *  Use this method to get version information
 */
+ (NSString *)getSDKVersion;
@end
